@@ -205,6 +205,8 @@ pub struct ArgminIterData<O: ArgminOp> {
     grad: Option<O::Param>,
     /// Current Hessian
     hessian: Option<O::Hessian>,
+    /// Current inverse Hessian
+    inv_hessian: Option<O::Hessian>,
     /// Current Jacobian
     jacobian: Option<O::Jacobian>,
     /// Current population
@@ -225,6 +227,7 @@ impl<O: ArgminOp> ArgminIterData<O> {
             cost: None,
             grad: None,
             hessian: None,
+            inv_hessian: None,
             jacobian: None,
             termination_reason: None,
             population: None,
@@ -256,6 +259,13 @@ impl<O: ArgminOp> ArgminIterData<O> {
         self
     }
 
+    /// Set inverse Hessian
+    #[must_use]
+    pub fn inv_hessian(mut self, inv_hessian: O::Hessian) -> Self {
+        self.inv_hessian = Some(inv_hessian);
+        self
+    }
+
     /// Set Jacobian
     pub fn jacobian(mut self, jacobian: O::Jacobian) -> Self {
         self.jacobian = Some(jacobian);
@@ -300,6 +310,11 @@ impl<O: ArgminOp> ArgminIterData<O> {
         self.hessian.clone()
     }
 
+    /// Get inverse Hessian
+    pub fn get_inv_hessian(&self) -> Option<O::Hessian> {
+        self.inv_hessian.clone()
+    }
+
     /// Get Jacobian
     pub fn get_jacobian(&self) -> Option<O::Jacobian> {
         self.jacobian.clone()
