@@ -7,8 +7,6 @@
 
 //! * [Hager-Zhang line search](struct.HagerZhangLineSearch.html)
 //!
-//! TODO: Not all stopping criteria implemented
-//!
 //! # Reference
 //!
 //! William W. Hager and Hongchao Zhang. "A new conjugate gradient method with guaranteed descent
@@ -32,7 +30,7 @@ type Triplet<F> = (F, F, F);
 /// DOI: <https://doi.org/10.1137/030601880>
 #[derive(Serialize, Deserialize, Clone)]
 pub struct HagerZhangLineSearch<P, F> {
-    /// delta: (0, 0.5), used in the Wolve conditions
+    /// delta: (0, 0.5), used in the Wolfe conditions
     delta: F,
     /// sigma: [delta, 1), used in the Wolfe conditions
     sigma: F,
@@ -41,7 +39,7 @@ pub struct HagerZhangLineSearch<P, F> {
     /// epsilon_k
     epsilon_k: F,
     /// theta: (0, 1), used in the update rules when the potential intervals [a, c] or [c, b]
-    /// viloate the opposite slope condition
+    /// violate the opposite slope condition
     theta: F,
     /// gamma: (0, 1), determines when a bisection step is performed
     gamma: F,
@@ -369,19 +367,19 @@ where
     }
 
     fn set_best(&mut self) {
-        if self.a_f < self.b_f && self.a_f < self.c_f {
+        if self.a_f <= self.b_f && self.a_f <= self.c_f {
             self.best_x = self.a_x;
             self.best_f = self.a_f;
             self.best_g = self.a_g;
         }
 
-        if self.b_f < self.a_f && self.b_f < self.c_f {
+        if self.b_f <= self.a_f && self.b_f <= self.c_f {
             self.best_x = self.b_x;
             self.best_f = self.b_f;
             self.best_g = self.b_g;
         }
 
-        if self.c_f < self.a_f && self.c_f < self.b_f {
+        if self.c_f <= self.a_f && self.c_f <= self.b_f {
             self.best_x = self.c_x;
             self.best_f = self.c_f;
             self.best_g = self.c_g;
@@ -533,10 +531,9 @@ where
     }
 
     fn terminate(&mut self, _state: &IterState<O>) -> TerminationReason {
-        if self.best_f - self.finit < self.delta * self.best_x * self.dginit {
-            return TerminationReason::LineSearchConditionMet;
-        }
-        if self.best_g > self.sigma * self.dginit {
+        if self.best_f - self.finit <= self.delta * self.best_x * self.dginit
+            && self.best_g >= self.sigma * self.dginit
+        {
             return TerminationReason::LineSearchConditionMet;
         }
         if (F::from_f64(2.0).unwrap() * self.delta - F::from_f64(1.0).unwrap()) * self.dginit
