@@ -9,7 +9,7 @@
 //!
 //! # References:
 //!
-//! [0] Jorge Nocedal and Stephen J. Wright (2006). Numerical Optimization.
+//! \[0\] Jorge Nocedal and Stephen J. Wright (2006). Numerical Optimization.
 //! Springer. ISBN 0-387-30303-0.
 
 use crate::prelude::*;
@@ -19,11 +19,9 @@ use serde::{Deserialize, Serialize};
 /// The Newton-CG method (also called truncated Newton method) uses a modified CG to solve the
 /// Newton equations approximately. After a search direction is found, a line search is performed.
 ///
-/// [Example](https://github.com/argmin-rs/argmin/blob/master/examples/newton_cg.rs)
-///
 /// # References:
 ///
-/// [0] Jorge Nocedal and Stephen J. Wright (2006). Numerical Optimization.
+/// \[0\] Jorge Nocedal and Stephen J. Wright (2006). Numerical Optimization.
 /// Springer. ISBN 0-387-30303-0.
 #[derive(Clone, Serialize, Deserialize)]
 pub struct NewtonCG<L, F> {
@@ -88,7 +86,7 @@ where
         + Default
         + ArgminInv<O::Hessian>
         + ArgminDot<O::Param, O::Param>,
-    L: Clone + ArgminLineSearch<O::Param, O::Float> + Solver<OpWrapper<O>>,
+    L: Clone + ArgminLineSearch<O::Param, O::Float> + Solver<O>,
     F: ArgminFloat + Default + ArgminDiv<O::Float, O::Float> + ArgminNorm<O::Float> + ArgminConj,
 {
     const NAME: &'static str = "Newton-CG";
@@ -149,15 +147,11 @@ where
                     cost: next_cost,
                     ..
                 },
-        } = Executor::new(
-            OpWrapper::new_from_wrapper(op),
-            self.linesearch.clone(),
-            param,
-        )
-        .grad(grad)
-        .cost(state.get_cost())
-        .ctrlc(false)
-        .run()?;
+        } = Executor::new(op.take_op().unwrap(), self.linesearch.clone(), param)
+            .grad(grad)
+            .cost(state.get_cost())
+            .ctrlc(false)
+            .run()?;
 
         op.consume_op(line_op);
 
