@@ -24,7 +24,7 @@ use std::fmt::Debug;
 #[derive(Clone, Serialize, Deserialize)]
 pub struct BFGS<L, H, F> {
     /// Inverse Hessian
-    inv_hessian: H,
+    init_inv_hessian: H,
     /// line search
     linesearch: L,
     /// Tolerance for the stopping criterion based on the change of the norm on the gradient
@@ -37,7 +37,7 @@ impl<L, H, F: ArgminFloat> BFGS<L, H, F> {
     /// Constructor
     pub fn new(init_inverse_hessian: H, linesearch: L) -> Self {
         BFGS {
-            inv_hessian: init_inverse_hessian,
+            init_inv_hessian: init_inverse_hessian,
             linesearch,
             tol_grad: F::epsilon().sqrt(),
             tol_cost: F::epsilon(),
@@ -94,7 +94,11 @@ where
         let cost = op.apply(&param)?;
         let grad = op.gradient(&param)?;
         Ok(Some(
-            ArgminIterData::new().param(param).cost(cost).grad(grad),
+            ArgminIterData::new()
+                .param(param)
+                .cost(cost)
+                .grad(grad)
+                .inv_hessian(self.init_inv_hessian.clone()),
         ))
     }
 
@@ -106,11 +110,9 @@ where
         let param = state.get_param();
         let cur_cost = state.get_cost();
         let prev_grad = state.get_grad().unwrap();
+        let inv_hessian = state.get_inv_hessian().unwrap();
 
-        let p = self
-            .inv_hessian
-            .dot(&prev_grad)
-            .mul(&F::from_f64(-1.0).unwrap());
+        let p = inv_hessian.dot(&prev_grad).mul(&F::from_f64(-1.0).unwrap());
 
         self.linesearch.set_search_direction(p);
 
@@ -145,7 +147,7 @@ where
         let yksk: F = yk.dot(&sk);
         let rhok = F::from_f64(1.0).unwrap() / yksk;
 
-        let e = self.inv_hessian.eye_like();
+        let e = inv_hessian.eye_like();
         let mat1: O::Hessian = sk.dot(&yk);
         let mat1 = mat1.mul(&rhok);
 
@@ -163,9 +165,13 @@ where
         //     println!("{:?}", self.inv_hessian);
         // }
 
-        self.inv_hessian = tmp1.dot(&self.inv_hessian.dot(&tmp2)).add(&sksk);
+        let inv_hessian = tmp1.dot(&inv_hessian.dot(&tmp2)).add(&sksk);
 
-        Ok(ArgminIterData::new().param(xk1).cost(next_cost).grad(grad))
+        Ok(ArgminIterData::new()
+            .param(xk1)
+            .cost(next_cost)
+            .grad(grad)
+            .inv_hessian(inv_hessian))
     }
 
     fn terminate(&mut self, state: &IterState<O>) -> TerminationReason {
