@@ -22,8 +22,8 @@ use serde::{Deserialize, Serialize};
 /// Springer. ISBN 0-387-30303-0.
 #[derive(Clone, Serialize, Deserialize)]
 pub struct DFP<L, H, F> {
-    /// Inverse Hessian
-    inv_hessian: H,
+    /// Initial inverse Hessian
+    init_inv_hessian: H,
     /// line search
     linesearch: L,
     /// Tolerance for the stopping criterion based on the change of the norm on the gradient
@@ -34,7 +34,7 @@ impl<L, H, F: ArgminFloat> DFP<L, H, F> {
     /// Constructor
     pub fn new(init_inverse_hessian: H, linesearch: L) -> Self {
         DFP {
-            inv_hessian: init_inverse_hessian,
+            init_inv_hessian: init_inverse_hessian,
             linesearch,
             tol_grad: F::epsilon().sqrt(),
         }
@@ -85,7 +85,11 @@ where
         let cost = op.apply(&param)?;
         let grad = op.gradient(&param)?;
         Ok(Some(
-            ArgminIterData::new().param(param).cost(cost).grad(grad),
+            ArgminIterData::new()
+                .param(param)
+                .cost(cost)
+                .grad(grad)
+                .inv_hessian(self.init_inv_hessian.clone()),
         ))
     }
 
@@ -96,15 +100,13 @@ where
     ) -> Result<ArgminIterData<O>, Error> {
         let param = state.get_param();
         let cost = state.get_cost();
+        let inv_hessian = state.get_inv_hessian().unwrap();
         let prev_grad = if let Some(grad) = state.get_grad() {
             grad
         } else {
             op.gradient(&param)?
         };
-        let p = self
-            .inv_hessian
-            .dot(&prev_grad)
-            .mul(&F::from_f64(-1.0).unwrap());
+        let p = inv_hessian.dot(&prev_grad).mul(&F::from_f64(-1.0).unwrap());
 
         self.linesearch.set_search_direction(p);
 
@@ -138,17 +140,20 @@ where
 
         let sksk: O::Hessian = sk.dot(&sk);
 
-        let tmp3: O::Param = self.inv_hessian.dot(&yk);
+        let tmp3: O::Param = inv_hessian.dot(&yk);
         let tmp4: F = tmp3.dot(&yk);
         let tmp3: O::Hessian = tmp3.dot(&tmp3);
         let tmp3: O::Hessian = tmp3.mul(&(F::from_f64(1.0).unwrap() / tmp4));
 
-        self.inv_hessian = self
-            .inv_hessian
+        let inv_hessian = inv_hessian
             .sub(&tmp3)
             .add(&sksk.mul(&(F::from_f64(1.0).unwrap() / yksk)));
 
-        Ok(ArgminIterData::new().param(xk1).cost(next_cost).grad(grad))
+        Ok(ArgminIterData::new()
+            .param(xk1)
+            .cost(next_cost)
+            .grad(grad)
+            .inv_hessian(inv_hessian))
     }
 
     fn terminate(&mut self, state: &IterState<O>) -> TerminationReason {
